@@ -37,6 +37,14 @@ const NonCriticalAnnotation = "networkoperator.openshift.io/non-critical"
 // that executing network migration (switching the default network type of the cluster) is allowed.
 const NetworkMigrationAnnotation = "networkoperator.openshift.io/network-migration"
 
+// OVNRaftClusterInitiator is an annotation on the networks.operator.openshift.io CR to indicate
+// which node IP was the raft cluster initiator. The NB and SB DB will be initialized by the same member.
+const OVNRaftClusterInitiator = "networkoperator.openshift.io/ovn-cluster-initiator"
+
+// RolloutHungAnnotation is set to "" if it is detected that a rollout
+// (i.e. DaemonSet or Deployment) is not making progress, unset otherwise.
+const RolloutHungAnnotation = "networkoperator.openshift.io/rollout-hung"
+
 // KuryrOctaviaProviderAnnotation is used to save latest Octavia provider that was configured in order to
 // prevent from reconfiguring it automatically when underlying Octavia changes.
 const KuryrOctaviaProviderAnnotation = "networkoperator.openshift.io/kuryr-octavia-provider"
@@ -44,10 +52,6 @@ const KuryrOctaviaProviderAnnotation = "networkoperator.openshift.io/kuryr-octav
 // KuryrOctaviaVersionAnnotation is used to save latest Octavia version detected
 const KuryrOctaviaVersionAnnotation = "networkoperator.openshift.io/kuryr-octavia-version"
 
-// SERVICE_CA_CONFIGMAP is the name of the ConfigMap that contains service CA bundle
-// that is used in multus admission controller deployment
-const SERVICE_CA_CONFIGMAP = "openshift-service-ca"
-
 // MULTUS_VALIDATING_WEBHOOK is the name of the ValidatingWebhookConfiguration for multus-admission-controller
 // that is used in multus admission controller deployment
 const MULTUS_VALIDATING_WEBHOOK = "multus.openshift.io"
