@@ -49,16 +49,23 @@ func renderOpenShiftSDN(conf *operv1.NetworkSpec, manifestDir string) ([]*uns.Un
 
 	kpcDefaults := map[string]operv1.ProxyArgumentList{
 		"metrics-bind-address":    {"0.0.0.0"},
-		"metrics-port":            {"29101"},
 		"healthz-port":            {"10256"},
 		"proxy-mode":              {"iptables"},
 		"iptables-masquerade-bit": {"0"},
 	}
-
-	kpcOverrides := map[string]operv1.ProxyArgumentList{}
+	// For backward compatibility we allow conf to specify `metrics-port: 9101` but
+	// the daemonset always configures 9101 as the secure metrics port and 29101 as
+	// the insecure metrics port exposed by kube-proxy itself. So just override
+	// the value from conf (which we know is either "9101" or unspecified).
+	kpcOverrides := map[string]operv1.ProxyArgumentList{
+		"metrics-port":  {"29101"},
+		"feature-gates": {"EndpointSlice=false,EndpointSliceProxying=false"},
+	}
 	if *c.EnableUnidling {
 		// We already validated that proxy-mode was either unset or iptables.
 		kpcOverrides["proxy-mode"] = operv1.ProxyArgumentList{"unidling+iptables"}
+	} else if *conf.DeployKubeProxy {
+		kpcOverrides["proxy-mode"] = operv1.ProxyArgumentList{"disabled"}
 	}
 
 	kpc, err := kubeProxyConfiguration(kpcDefaults, conf, kpcOverrides)
@@ -113,8 +120,14 @@ func validateOpenShiftSDN(conf *operv1.NetworkSpec) []error {
 		}
 	}
 
-	proxyErrs := validateKubeProxy(conf)
-	out = append(out, proxyErrs...)
+	if conf.DeployKubeProxy != nil && *conf.DeployKubeProxy {
+		// We allow deploying an external kube-proxy with openshift-sdn in very
+		// limited circumstances, for testing purposes. The error here
+		// intentionally lies about this.
+		if sc == nil || sc.EnableUnidling == nil || *sc.EnableUnidling || !noKubeProxyConfig(conf) {
+			out = append(out, errors.Errorf("openshift-sdn does not support 'deployKubeProxy: true'"))
+		}
+	}
 
 	return out
 }
@@ -164,7 +177,6 @@ func fillOpenShiftSDNDefaults(conf, previous *operv1.NetworkSpec, hostMTU int) {
 	if conf.KubeProxyConfig.BindAddress == "" {
 		conf.KubeProxyConfig.BindAddress = "0.0.0.0"
 	}
-
 	if conf.KubeProxyConfig.ProxyArguments == nil {
 		conf.KubeProxyConfig.ProxyArguments = map[string]operv1.ProxyArgumentList{}
 	}
